var test = require('tape')
var basicTests = require('./basic-tests')
var http = require('http')
var httpProxy = require('http-proxy')

var etcdServer = 'localhost:4001'

basicTests.run('singleton', etcdServer)
basicTests.run('singleton', 'etcd://' + etcdServer)

var proxy = httpProxy.createProxyServer()
var server1 = http.createServer(serverHandler)
var server2 = http.createServer(serverHandler)

var server1Port
var server2Port

var server1Requests = 0
var server2Requests = 0

server1.listen(0, function () {
  server1Port = server1.address().port

  server2.listen(0, function () {
    server2Port = server2.address().port
    startClusterTest()
  })
})

function startClusterTest () {
  var server1Addr = 'localhost:' + server1Port
  var server2Addr = 'localhost:' + server2Port

  basicTests.run('cluster', server1Addr + ',' + server2Addr)

  var longServerAddr = '  etcd://' + server1Addr + ' , etcd://' + server2Addr + '  '
  basicTests.run('cluster', longServerAddr)

  test('ensure both proxies had requests', function (t) {
    console.log('server requests:', server1Requests, server2Requests)
    t.ok(server1Requests > 0, 'server 1 got requests')
    t.ok(server2Requests > 0, 'server 2 got requests')
    t.end()
  })

  test('close proxy ports', function (t) {
    server1.close()
    server2.close()
    t.end()
  })
}

function serverHandler (req, res) {
  var port = req.headers.host.split(':')[1]

  if (+port === server1Port) server1Requests++
  else if (+port === server2Port) server2Requests++
  else throw new Error('unexpected port for request from ' + req.headers.host)

  proxy.web(req, res, {target: 'http://' + etcdServer})
}
