#!/bin/sh
// 2>/dev/null; exec "`dirname "$0"`/nsolid" "$0" "$@"
'use strict'

var rc = require('rc')
var cli = require('./cli')
var formats = require('./cli_formats')

var conf = rc('nsolid-cli', {
  hub: 'http://localhost:9000'
})

if (conf.h || conf.help) {
  const helpFile = require('path').join(__dirname, 'help.txt')
  const helpText = require('fs').readFileSync(helpFile)
  console.error(String(helpText))
  process.exit(0)
}

if (conf._.length === 0) {
  usageError('Expecting a command: ping, snapshot, etc. Use -h for list of commands.')
}

if (conf._.length > 1) {
  usageError('Expecting only a single command')
}

var command = conf._[0]

// aliases: socket > agent > hub
var remoteSocket = '' + (conf.socket || conf.agent || conf.hub)
if (remoteSocket.indexOf(':') < 0) {
  remoteSocket = 'localhost:' + remoteSocket
}

// TODO allow data to be piped instead of just a single flag

try {
  var out = cli(command, remoteSocket, conf)
} catch (err) {
  usageError(err.message)
}

out.on('error', function (err) {
  usageError('Error trying to connect to N|Solid: ' + err)
})

out
  .pipe(formats.Consolize())
  .pipe(process.stdout)

function usageError (message) {
  console.error(message)
  process.exit(1)
}
